@@ -19,17 +19,17 @@
 ( cd usr/bin ; rm -rf ldapadd )
 ( cd usr/bin ; ln -sf ldapmodify ldapadd )
 ( cd usr/lib ; rm -rf liblber.so )
-( cd usr/lib ; ln -sf liblber-2.4.so.2.5.6 liblber.so )
+( cd usr/lib ; ln -sf liblber-2.4.so.2.6.0 liblber.so )
 ( cd usr/lib ; rm -rf liblber-2.4.so.2 )
-( cd usr/lib ; ln -sf liblber-2.4.so.2.5.6 liblber-2.4.so.2 )
+( cd usr/lib ; ln -sf liblber-2.4.so.2.6.0 liblber-2.4.so.2 )
 ( cd usr/lib ; rm -rf libldap.so )
-( cd usr/lib ; ln -sf libldap-2.4.so.2.5.6 libldap.so )
+( cd usr/lib ; ln -sf libldap-2.4.so.2.6.0 libldap.so )
 ( cd usr/lib ; rm -rf libldap-2.4.so.2 )
-( cd usr/lib ; ln -sf libldap-2.4.so.2.5.6 libldap-2.4.so.2 )
+( cd usr/lib ; ln -sf libldap-2.4.so.2.6.0 libldap-2.4.so.2 )
 ( cd usr/lib ; rm -rf libldap_r.so )
-( cd usr/lib ; ln -sf libldap_r-2.4.so.2.5.6 libldap_r.so )
+( cd usr/lib ; ln -sf libldap_r-2.4.so.2.6.0 libldap_r.so )
 ( cd usr/lib ; rm -rf libldap_r-2.4.so.2 )
-( cd usr/lib ; ln -sf libldap_r-2.4.so.2.5.6 libldap_r-2.4.so.2 )
+( cd usr/lib ; ln -sf libldap_r-2.4.so.2.6.0 libldap_r-2.4.so.2 )
 ( cd usr/share/man/man1 ; rm -rf ldapadd.1.gz )
 ( cd usr/share/man/man1 ; ln -sf ldapmodify.1.gz ldapadd.1.gz )
 ( cd usr/share/man/man3 ; rm -rf ber_alloc_t.3.gz )
@@ -156,6 +156,8 @@
 ( cd usr/share/man/man3 ; ln -sf ldap_delete.3.gz ldap_delete_ext_s.3.gz )
 ( cd usr/share/man/man3 ; rm -rf ldap_delete_s.3.gz )
 ( cd usr/share/man/man3 ; ln -sf ldap_delete.3.gz ldap_delete_s.3.gz )
+( cd usr/share/man/man3 ; rm -rf ldap_destroy.3.gz )
+( cd usr/share/man/man3 ; ln -sf ldap_dup.3.gz ldap_destroy.3.gz )
 ( cd usr/share/man/man3 ; rm -rf ldap_dn2ad_canonical.3.gz )
 ( cd usr/share/man/man3 ; ln -sf ldap_get_dn.3.gz ldap_dn2ad_canonical.3.gz )
 ( cd usr/share/man/man3 ; rm -rf ldap_dn2dcedn.3.gz )
@@ -180,6 +182,8 @@
 ( cd usr/share/man/man3 ; ln -sf ldap_get_values.3.gz ldap_get_values_len.3.gz )
 ( cd usr/share/man/man3 ; rm -rf ldap_init.3.gz )
 ( cd usr/share/man/man3 ; ln -sf ldap_open.3.gz ldap_init.3.gz )
+( cd usr/share/man/man3 ; rm -rf ldap_init_fd.3.gz )
+( cd usr/share/man/man3 ; ln -sf ldap_open.3.gz ldap_init_fd.3.gz )
 ( cd usr/share/man/man3 ; rm -rf ldap_initialize.3.gz )
 ( cd usr/share/man/man3 ; ln -sf ldap_open.3.gz ldap_initialize.3.gz )
 ( cd usr/share/man/man3 ; rm -rf ldap_install_tls.3.gz )
@@ -264,6 +268,8 @@
 ( cd usr/share/man/man3 ; ln -sf ldap_get_option.3.gz ldap_set_option.3.gz )
 ( cd usr/share/man/man3 ; rm -rf ldap_set_rebind_proc.3.gz )
 ( cd usr/share/man/man3 ; ln -sf ldap_bind.3.gz ldap_set_rebind_proc.3.gz )
+( cd usr/share/man/man3 ; rm -rf ldap_set_urllist_proc.3.gz )
+( cd usr/share/man/man3 ; ln -sf ldap_open.3.gz ldap_set_urllist_proc.3.gz )
 ( cd usr/share/man/man3 ; rm -rf ldap_simple_bind.3.gz )
 ( cd usr/share/man/man3 ; ln -sf ldap_bind.3.gz ldap_simple_bind.3.gz )
 ( cd usr/share/man/man3 ; rm -rf ldap_simple_bind_s.3.gz )
@@ -314,7 +320,7 @@
 ( cd usr/share/man/man3 ; ln -sf ldap_get_values.3.gz ldap_value_free_len.3.gz )
 ( cd usr/share/man/man5 ; rm -rf slapd-hdb.5.gz )
 ( cd usr/share/man/man5 ; ln -sf slapd-bdb.5.gz slapd-hdb.5.gz )
-#%% begin initialize openldap-2.4.23-i586-P1
+#%% begin initialize openldap-2.4.24-i586-P1
 if [ ! -f /var/openldap-data/DB_CONFIG ]; then
   cd /var/openldap-data ; cp DB_CONFIG.example DB_CONFIG
 fi
